ChildWorkflowInput

Struct ChildWorkflowInput 

pub struct ChildWorkflowInput {
    pub inputs: HashMap<String, String>,
    pub iteration: u32,
    pub as_identity: Option<String>,
    pub depth: u32,
    pub parent_step_id: Option<String>,
    pub cancellation: CancellationToken,
}
Input parameters for child workflow execution.

Fields

inputs: HashMap<String, String>iteration: u32as_identity: Option<String>depth: u32parent_step_id: Option<String>cancellation: CancellationToken

Child token derived from the parent run’s cancellation token. The child runner sets this as the child ExecutionState.cancellation so that cancelling the parent automatically cancels in-progress child runs.